﻿#include <QtCore/QtDebug>
#include "BiggestCitiesModel.h"
#include "CityComponent.h"
#include "CityDatabase.h"
#include "TranslationManager.h"

BiggestCitiesModel::BiggestCitiesModel(QObject *parent) :
  QAbstractListModel(parent)
{
    m_roles[ROLE_CITY_COMPONENT] = "city";
    connect(TranslationManager::instance(), SIGNAL(languageChanged(QString)),
            this, SLOT(retranslate(QString)));
}

BiggestCitiesModel::~BiggestCitiesModel()
{
}

void BiggestCitiesModel::retranslate(const QString &language)
{
    emit titleChanged();
    CityDatabase::instance()->retranslate(language);
    emit dataChanged(index(0), index(m_cities.count() - 1));
}

const QString &BiggestCitiesModel::country() const
{
    return m_country;
}

void BiggestCitiesModel::setCountry(const QString &country)
{
    if (m_country != country)
    {
        beginResetModel();
        m_cities = CityDatabase::instance()->citiesOfCountry(country);
        endResetModel();

        m_country = country;
        countryChanged();
    }
}

QString BiggestCitiesModel::title() const
{
    return tr(rawTitle());
}

const char *BiggestCitiesModel::rawTitle()
{
    static const char *title = QT_TR_NOOP("German Cities");
    return title;
}

QVariant BiggestCitiesModel::data(const QModelIndex &index, int role) const
{
    if (!index.isValid() || index.row() < 0 || index.row() >= rowCount())
        return QVariant();

    if (role == ROLE_CITY_COMPONENT) {
        QVariant v;
        v.setValue(static_cast<QObject *>(m_cities[index.row()]));
        return v;
    }
    else {
        return QVariant();
    }
}

QModelIndex BiggestCitiesModel::parent(const QModelIndex &index) const
{
    Q_UNUSED(index)
    return QModelIndex();
}

int BiggestCitiesModel::rowCount(const QModelIndex &parent) const
{
    Q_UNUSED(parent)
    return m_cities.count();
}

QHash<int, QByteArray> BiggestCitiesModel::roleNames() const
{
    return m_roles;
}
