﻿#include <QtCore/QEvent>
#include <QtCore/QMap>
#include <QtCore/QtDebug>
#include "CityComponent.h"
#include "CityDatabase.h"
#include "TranslationManager.h"

const char *CityDatabase::m_strings[][2] = {
    { QT_TR_NOOP("Berlin"), QT_TR_NOOP("Berlin") },
    { QT_TR_NOOP("Hamburg"), QT_TR_NOOP("Hamburg") },
    { QT_TR_NOOP("Munich"), QT_TR_NOOP("Bavaria") },
    { QT_TR_NOOP("Cologne"), QT_TR_NOOP("North Rhine-Westphalia") },
    { QT_TR_NOOP("Frankfurt am Main"), QT_TR_NOOP("Hesse") },
    { QT_TR_NOOP("Stuttgart"), QT_TR_NOOP("Baden-Wuerttemberg") },
    { QT_TR_NOOP("Dusseldorf"), QT_TR_NOOP("North Rhine-Westphalia") },
    { QT_TR_NOOP("Dortmund"), QT_TR_NOOP("North Rhine-Westphalia") },
    { QT_TR_NOOP("Essen"), QT_TR_NOOP("North Rhine-Westphalia") },
    { QT_TR_NOOP("Bremen"), QT_TR_NOOP("Bremen") },
    { QT_TR_NOOP("Dresden"), QT_TR_NOOP("Saxony") },
    { QT_TR_NOOP("Leipzig"), QT_TR_NOOP("Saxony") },
    { QT_TR_NOOP("Hanover"), QT_TR_NOOP("Lower Saxony") },
    { QT_TR_NOOP("Nuremberg"), QT_TR_NOOP("Bavaria") },
    { QT_TR_NOOP("Duisburg"), QT_TR_NOOP("North Rhine-Westphalia") },
    { QT_TR_NOOP("Bochum"), QT_TR_NOOP("North Rhine-Westphalia") },
    { QT_TR_NOOP("Wuppertal"), QT_TR_NOOP("North Rhine-Westphalia") },
    { QT_TR_NOOP("Bonn"), QT_TR_NOOP("North Rhine-Westphalia") },
    { QT_TR_NOOP("Bielefeld"), QT_TR_NOOP("North Rhine-Westphalia") },
    { QT_TR_NOOP("Mannheim"), QT_TR_NOOP("Baden Wuerttemberg") },
    { 0, 0 }
};

struct CityDatabasePrivate
{
    QMap<int, CityComponent*> m_cities;
    QString m_currentLanguage;
};


CityDatabase::CityDatabase() :
    QObject(0),
    m_d(new CityDatabasePrivate)
{
    connect(TranslationManager::instance(), SIGNAL(languageChanged(QString)),
            this, SLOT(retranslate(QString)));

    m_d->m_cities.insert(0, new CityComponent(0, tr(m_strings[0][0]), tr(m_strings[0][1]), "de", 3461000));
    m_d->m_cities.insert(1, new CityComponent(1, tr(m_strings[1][0]), tr(m_strings[1][1]), "de", 1786000));
    m_d->m_cities.insert(2, new CityComponent(2, tr(m_strings[2][0]), tr(m_strings[2][1]), "de", 1353000));
    m_d->m_cities.insert(3, new CityComponent(3, tr(m_strings[3][0]), tr(m_strings[3][1]), "de", 1007000));
    m_d->m_cities.insert(4, new CityComponent(4, tr(m_strings[4][0]), tr(m_strings[4][1]), "de", 680000));
    m_d->m_cities.insert(5, new CityComponent(5, tr(m_strings[5][0]), tr(m_strings[5][1]), "de", 607000));
    m_d->m_cities.insert(6, new CityComponent(6, tr(m_strings[6][0]), tr(m_strings[6][1]), "de", 589000));
    m_d->m_cities.insert(7, new CityComponent(7, tr(m_strings[7][0]), tr(m_strings[7][1]), "de", 580000));
    m_d->m_cities.insert(8, new CityComponent(8, tr(m_strings[8][0]), tr(m_strings[8][1]), "de", 575000));
    m_d->m_cities.insert(9, new CityComponent(9, tr(m_strings[9][0]), tr(m_strings[9][1]), "de", 547000));
    m_d->m_cities.insert(10, new CityComponent(10, tr(m_strings[10][0]), tr(m_strings[10][1]), "de", 523000));
    m_d->m_cities.insert(11, new CityComponent(11, tr(m_strings[11][0]), tr(m_strings[11][1]), "de", 523000));
    m_d->m_cities.insert(12, new CityComponent(12, tr(m_strings[12][0]), tr(m_strings[12][1]), "de", 523000));
    m_d->m_cities.insert(13, new CityComponent(13, tr(m_strings[13][0]), tr(m_strings[13][1]), "de", 506000));
    m_d->m_cities.insert(14, new CityComponent(14, tr(m_strings[14][0]), tr(m_strings[14][1]), "de", 490000));
    m_d->m_cities.insert(15, new CityComponent(15, tr(m_strings[15][0]), tr(m_strings[15][1]), "de", 375000));
    m_d->m_cities.insert(16, new CityComponent(16, tr(m_strings[16][0]), tr(m_strings[16][1]), "de", 350000));
    m_d->m_cities.insert(17, new CityComponent(17, tr(m_strings[17][0]), tr(m_strings[17][1]), "de", 325000));
    m_d->m_cities.insert(18, new CityComponent(18, tr(m_strings[18][0]), tr(m_strings[18][1]), "de", 323000));
    m_d->m_cities.insert(19, new CityComponent(19, tr(m_strings[19][0]), tr(m_strings[19][1]), "de", 313000));
}

CityDatabase::~CityDatabase()
{
    delete m_d;
}

CityDatabase *CityDatabase::instance()
{
    static CityDatabase cityDatabase;
    return &cityDatabase;
}

void CityDatabase::retranslate(const QString &language)
{
    // Guard against multipe retranslations triggered by multiple clients
    // using CityDatabase.
    if (m_d->m_currentLanguage != language)
    {
        for (int i = 0; i < m_d->m_cities.count(); ++i) {
            m_d->m_cities[i]->setName(tr(m_strings[i][0]));
            m_d->m_cities[i]->setState(tr(m_strings[i][1]));
        }
        m_d->m_currentLanguage = language;
    }
}

QList<CityComponent*> CityDatabase::citiesOfCountry(const QString &country) const
{
    QList<CityComponent*> result;
    foreach (CityComponent *cc, m_d->m_cities) {
        if (cc->countryID() == country)
            result.append(cc);
    }
    return result;
}
