/**
  * A button for both key and mouse interaction is in one of three states:
  * 1) "" - This is the inital or normal state. The button has neither the key nor mouse focus.
  * 2) "focused" - The button has the key focus and shows the normal cursor. This indicates
  *    that the user can trigger the buttons action by pressing the Return key. This state
  *    does not exist for mouse interaction, because pressing a button with the mouse does
  *    the focusing and pressing in one step.
  * 3) "pressed" - The user has either pressed the button with the mouse or has pressed Return
  *    on a button in state "focused". The button shows the pressed cursor.
  */

import QtQuick 2.1

FocusScope
{
    id: root

    signal released()

    property Item backtabDown: cursor.backtabDown
    property Item tabDown: cursor.tabDown
    property Item backtabUp
    property Item tabUp

    property alias _buttonLook: loader

    function handleBacktab()
    {
        cursor.handleBacktab()
    }

    function handleTab()
    {
        cursor.handleTab()
    }

    width: 120
    height: 80

    Image
    {
        id: background
        anchors.fill: parent
        source: g_theme.baseButton.backgroundImage

        Loader
        {
            id: loader
            anchors.margins: 8
            anchors.centerIn: parent
        }

        ButtonCursor
        {
            id: cursor
            anchors.fill: parent
            objectName: "cursor of button " + root.objectName
            focus: true
            backtabUp: root.backtabUp
            tabUp: root.tabUp
            onReleased: root.released()
        }
    }
}
