import QtQuick 2.1

FocusScope
{
    id: root

    signal released()

    property Item backtabDown: root
    property Item tabDown: root
    property Item backtabUp
    property Item tabUp

    BorderImage
    {
        id: cursorShape
        anchors.fill: parent
        border { left: 8; top: 8; right: 8; bottom: 8 }
        source: g_theme.cursor.iconNoCursor
    }

    MouseArea
    {
        id: mouseArea
        anchors.fill: parent

        onPressed: {
            root.handleMousePress()
            root.state = "pressed"
            mouse.accepted = true
        }

        onReleased: {
            if (root.activeFocus) {
                root.state = "focused"
                root.released()
            }
            mouse.accepted = true
        }
    }

    Keys.onBacktabPressed: {
        root.backtabUp.handleBacktab()
        event.accepted = true
    }

    Keys.onTabPressed: {
        root.tabUp.handleTab()
        event.accepted = true
    }

    // NOTE: QTBUG-21500: isAutoRepeat is always false, because autoRepeat is
    // not forwarded in qnsview.mm (src/plugins/platforms/cocoa). The simple
    // fix given in https://bugreports.qt-project.org/browse/QTBUG-21500 works.
    // Bug exists in Qt 5.0.2 and Qt 5.1.1 and probably other versions.
    // Qt 4.8 works fine.
    Keys.onPressed: {
        if (event.key === Qt.Key_Return && !event.isAutoRepeat) {
//            console.log("# Return pressed on ", root.objectName)
            root.state = "pressed"
        }
        event.accepted = true
    }

    Keys.onReleased: {
        if (event.key === Qt.Key_Return && root.state === "pressed") {
//            console.log("# Return released on ", root.objectName)
            root.state = "focused"
            root.released();
        }
        event.accepted = true
    }

    states: [
        State {
            name: ""
            when: !root.activeFocus
            PropertyChanges { target: cursorShape; source: g_theme.cursor.iconNoCursor }
        },
        State {
            name: "focused"
            when: root.activeFocus
            PropertyChanges { target: cursorShape; source: g_theme.cursor.iconFocusedCursor }
        },
        State {
            name: "pressed"
            PropertyChanges { target: cursorShape; source: g_theme.cursor.iconPressedCursor }
        }
    ]

}
