﻿import QtQuick 2.1
import QtQuick.Controls 1.0

FocusScope
{
    id: mainPage

    property string title

    // NOTE: Whenever an item of the stack view becomes active, the active focus
    //     must be passed to this item. Doing this when Component.onCompleted is called,
    //     is not enough, because an item can be active and inactive multiple times
    //     during its life cycle.
    //     Setting the active focus to this item (mainPage) only works, if "derived"
    //     items like MainMenu or BiggestCitiesPage request the focus (that is, focus: true)
    //     for one of their subitems.
    Stack.onStatusChanged: {
        if (Stack.status === Stack.Active) {
            mainPage.forceActiveFocus()
        }
    }

    // If a dialog is shown on top of a main page, we must prevent mouse presses
    // from leaving the dialog page. Without catching the mouse presses, the user
    // could still trigger actions by clicking on mouse areas on the main page below.
    // By the way, it doesn't matter whether the lower page is covered opaquely or
    // transparently by the upper page. The mouse areas would always be active.
    MouseArea
    {
        anchors.fill: parent
        onPressed: mouse.accepted = true
    }

}
