import QtQuick 2.1
import QtQuick.Controls 1.0


// NOTE: Even if the top item of MainMenu is not a FocusScope and the active
//     focus is not set when the stack view changes the item's status to "active",
//     the cursor is set correctly to the top-left flag. The reason is that the
//     the QQuickView gets the "application" focus and passes it on to the QML
//     files loaded. Hence, the StackView and its initial item, the MainMenu,
//     get the active focus.
//     If we used MainMenu deeper down on the stack, the cursor would not work
//     any more. This can be demonstrated by "deriving" BiggestCitiesPage from
//     a Rectangle instead of a FocusScope.
BaseMainPage
{
    id: root

    title: qsTr("Main Menu") + g_tr.languageChanged

    Rectangle
    {
        anchors.fill: parent
        color: g_theme.centralArea.backgroundColor

        Column
        {
            Toolbar
            {
                id: toolbar
                objectName: "toolbar"
                title: root.title
                isTopPage: true
            }

            MenuEurope
            {
                id: menuEurope
                objectName: "menuEurope"
                backtabUp: tabbar.backtabDown
                tabUp: tabbar.tabDown
                focus: true
            }

            Tabbar
            {
                id: tabbar
                objectName: "tabbar"
                backtabUp: menuEurope.backtabDown
                tabUp: menuEurope.tabDown
            }
        }
    }
}
