import QtQuick 2.1

FocusScope
{
    id: root

    property Item backtabDown: buttonBelgium.backtabDown
    property Item tabDown: buttonSpain.tabDown
    property Item backtabUp
    property Item tabUp

    width: 1024
    height: 588

    Grid
    {
        id: menuGrid
        anchors.centerIn: parent
        rows: 3
        columns: 4
        spacing: 12

        FlagButton {
            id: buttonSpain
            objectName: "FlagButtonSpain"
            source: g_theme.flagButton.europe.spain
            focus: true
            // None of the following two commands can work, because the active focus is still with
            // MenuEurope and because both commands only move the focus (not the active focus).
            // Keep in mind that a widget only gets the focus once its surrounding focus scope gets
            // the active focus. And, the toolbar doesn't have the active focus.
//            Keys.onBacktabPressed: root.backtabOut.focus = true
//            backtabUp: root.backtabOut
            backtabUp: root.backtabUp
            tabUp: buttonGermany.tabDown
        }       
        FlagButton {
            id: buttonGermany
            objectName: "FlagButtonGermany"
            source: g_theme.flagButton.europe.germany
            backtabUp: buttonSpain.backtabDown
            tabUp: buttonUK.tabDown
            onReleased: {
                g_mainPageStack.push({
                                         item: Qt.resolvedUrl("BiggestCitiesPage.qml"),
                                         properties: { country: "de" }
                                     })
            }
        }
        FlagButton {
            id: buttonUK
            objectName: "FlagButtonUK"
            source: g_theme.flagButton.europe.uk
            backtabUp: buttonGermany.backtabDown
            tabUp: buttonItaly.tabDown
        }
        FlagButton {
            id: buttonItaly
            objectName: "FlagButtonItaly"
            source: g_theme.flagButton.europe.italy
            backtabUp: buttonUK.backtabDown
            tabUp: buttonFrance.tabDown
        }

        FlagButton {
            id: buttonFrance
            objectName: "FlagButtonFrance"
            source: g_theme.flagButton.europe.france
            backtabUp: buttonItaly.backtabDown
            tabUp: buttonPortugal.tabDown
        }
        FlagButton {
            id: buttonPortugal
            objectName: "FlagButtonPortugal"
            source: g_theme.flagButton.europe.portugal
            backtabUp: buttonFrance.backtabDown
            tabUp: buttonNetherlands.tabDown
        }
        FlagButton {
            id: buttonNetherlands
            objectName: "FlagButtonNetherlands"
            source: g_theme.flagButton.europe.netherlands
            backtabUp: buttonPortugal.backtabDown
            tabUp: buttonDenmark.tabDown
        }
        FlagButton {
            id: buttonDenmark
            objectName: "FlagButtonDenmark"
            source: g_theme.flagButton.europe.denmark
            backtabUp: buttonNetherlands.backtabDown
            tabUp: buttonGreece.tabDown
        }

        FlagButton {
            id: buttonGreece
            objectName: "FlagButtonGreece"
            source: g_theme.flagButton.europe.greece
            backtabUp: buttonDenmark.backtabDown
            tabUp: buttonRussia.tabDown
        }
        FlagButton {
            id: buttonRussia
            objectName: "FlagButtonRussia"
            source: g_theme.flagButton.europe.russia
            backtabUp: buttonGreece.backtabDown
            tabUp: buttonAustria.tabDown
        }
        FlagButton {
            id: buttonAustria
            objectName: "FlagButtonAustria"
            source: g_theme.flagButton.europe.austria
            backtabUp: buttonRussia.backtabDown
            tabUp: buttonBelgium.tabDown
        }
        FlagButton {
            id: buttonBelgium
            objectName: "FlagButtonBelgium"
            source: g_theme.flagButton.europe.belgium
            backtabUp: buttonAustria.backtabDown
            tabUp: root.tabUp
            // We could use the KeyNavigation property for every FlagButton except for the top-left
            // and the bottom-right corner, where would have to use the Keys event handlers instead.
            // We think that it is a better solution to specify the tab and backtab connections
            // through the tabOut and backtabUp properties and do the actual work in one place,
            // namely in BaseButton (see the event handlers onTabPressed and onBacktabPressed there).
            // It is a more uniform and more localised solution - and less duplciated code.
//            backtabUp: buttonAustria
//            Keys.onTabPressed: root.tabOut.forceActiveFocus()
        }
    }
}
