﻿import QtQuick 2.1

FocusScope
{
    id: root

    signal result(bool accepted, int number)

    property int number: 0
    property int originalNumber: 0

    width: childrenRect.width
    height: childrenRect.height

    function handleBacktab()
    {
        buttonAccept.forceActiveFocus()
    }

    function handleTab()
    {
        buttonMinus100K.forceActiveFocus()
    }

    function changeValueBy(factor, offset)
    {
        root.number = factor * root.number + offset
        if (root.number < 0)
            root.number = 0
        else if (root.number >= 100000000)
            root.number = 100000000
        root.numberChanged(root.number)
    }

    Rectangle
    {
        width: childrenRect.width + 32
        height: childrenRect.height + 32
        color: g_theme.numberInput.backgroundColor

        Grid
        {
            id: numberPad

            property real rowHeight: 64
            property real columnWidthPlusMinus: 160
            property real columnWidthDigit: 80
            property real columnWidthSpecial: 120

            x: 16
            y: 16
            rows: 4
            columns: 6
            spacing: 16

            // *** First Row
            PushButton
            {
                id: buttonMinus100K
                objectName: "buttonMinus100K"
                width: numberPad.columnWidthPlusMinus
                height: numberPad.rowHeight
                text: "-100000"
                backtabUp: buttonAccept
                tabUp: buttonDigit7
                onReleased: changeValueBy(1, -100000)
            }

            PushButton
            {
                id: buttonDigit7
                objectName: "buttonDigit7"
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
                text: "7"
                backtabUp: buttonMinus100K
                tabUp: buttonDigit8
                onReleased: changeValueBy(10, 7)
            }

            PushButton
            {
                id: buttonDigit8
                objectName: "buttonDigit8"
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
                text: "8"
                backtabUp: buttonDigit7
                tabUp: buttonDigit9
                onReleased: changeValueBy(10, 8)
            }

            PushButton
            {
                id: buttonDigit9
                objectName: "buttonDigit9"
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
                text: "9"
                backtabUp: buttonDigit8
                tabUp: buttonBackspace
                onReleased: changeValueBy(10, 9)
            }

            ToolButton
            {
                id: buttonBackspace
                objectName: "buttonBackspace"
                width: numberPad.columnWidthSpecial
                height: numberPad.rowHeight
                source: g_theme.numberInput.iconBackspace
                backtabUp: buttonDigit9
                tabUp: buttonPlus100K
                onReleased: root.changeValueBy(0.1, 0)
            }

            PushButton
            {
                id: buttonPlus100K
                objectName: "buttonPlus100K"
                width: numberPad.columnWidthPlusMinus
                height: numberPad.rowHeight
                text: "+100000"
                backtabUp: buttonBackspace
                tabUp: buttonMinus10K
                onReleased: changeValueBy(1, 100000)
            }

            // *** Second Row
            PushButton
            {
                id: buttonMinus10K
                objectName: "buttonMinus10K"
                width: numberPad.columnWidthPlusMinus
                height: numberPad.rowHeight
                text: "-10000"
                backtabUp: buttonPlus100K
                tabUp: buttonDigit4
                onReleased: changeValueBy(1, -10000)
            }

            PushButton
            {
                id: buttonDigit4
                objectName: "buttonDigit4"
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
                text: "4"
                backtabUp: buttonMinus10K
                tabUp: buttonDigit5
                onReleased: changeValueBy(10, 4)
            }

            PushButton
            {
                id: buttonDigit5
                objectName: "buttonDigit5"
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
                text: "5"
                backtabUp: buttonDigit4
                tabUp: buttonDigit6
                onReleased: changeValueBy(10, 5)
            }

            PushButton
            {
                id: buttonDigit6
                objectName: "buttonDigit6"
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
                text: "6"
                backtabUp: buttonDigit5
                tabUp: buttonClear
                onReleased: changeValueBy(10, 6)
            }

            PushButton
            {
                id: buttonClear
                objectName: "buttonClear"
                width: numberPad.columnWidthSpecial
                height: numberPad.rowHeight
                text: "CLR"
                backtabUp: buttonDigit6
                tabUp: buttonPlus10K
                onReleased: root.number = 0
            }

            PushButton
            {
                id: buttonPlus10K
                objectName: "buttonPlus10K"
                width: numberPad.columnWidthPlusMinus
                height: numberPad.rowHeight
                text: "+10000"
                backtabUp: buttonClear
                tabUp: buttonMinus1K
                onReleased: changeValueBy(1, 10000)
            }

            // *** Third Row
            PushButton
            {
                id: buttonMinus1K
                objectName: "buttonMinus1K"
                width: numberPad.columnWidthPlusMinus
                height: numberPad.rowHeight
                text: "-1000"
                backtabUp: buttonPlus10K
                tabUp: buttonDigit1
                onReleased: changeValueBy(1, -1000)
            }

            PushButton
            {
                id: buttonDigit1
                objectName: "buttonDigit1"
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
                text: "1"
                backtabUp: buttonMinus1K
                tabUp: buttonDigit2
                onReleased: changeValueBy(10, 1)
            }

            PushButton
            {
                id: buttonDigit2
                objectName: "buttonDigit2"
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
                text: "2"
                backtabUp: buttonDigit1
                tabUp: buttonDigit3
                onReleased: changeValueBy(10, 2)
            }

            PushButton
            {
                id: buttonDigit3
                objectName: "buttonDigit3"
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
                text: "3"
                backtabUp: buttonDigit2
                tabUp: buttonDigit0
                onReleased: changeValueBy(10, 3)
            }

            PushButton
            {
                id: buttonDigit0
                objectName: "buttonDigit0"
                width: numberPad.columnWidthSpecial
                height: numberPad.rowHeight
                text: "0"
                backtabUp: buttonDigit3
                tabUp: buttonPlus1K
                onReleased: changeValueBy(10, 0)
            }

            PushButton
            {
                id: buttonPlus1K
                objectName: "buttonPlus1K"
                width: numberPad.columnWidthPlusMinus
                height: numberPad.rowHeight
                text: "+1000"
                backtabUp: buttonDigit0
                tabUp: buttonReject
                onReleased: changeValueBy(1, 1000)
            }

            // *** Fourth Row
            ToolButton {
                id: buttonReject
                objectName: "ToolButtonReject"
                width: numberPad.columnWidthPlusMinus
                height: numberPad.rowHeight
                backtabUp: buttonPlus1K
                tabUp: buttonAccept
                source: g_theme.numberInput.iconReject
                onReleased: root.result(false, root.originalNumber)
            }

            Item
            {
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
            }

            Item
            {
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
            }

            Item
            {
                width: numberPad.columnWidthDigit
                height: numberPad.rowHeight
            }

            Item
            {
                width: numberPad.columnWidthSpecial
                height: numberPad.rowHeight
            }

            ToolButton {
                id: buttonAccept
                objectName: "ToolButtonAccept"
                width: numberPad.columnWidthPlusMinus
                height: numberPad.rowHeight
                source: g_theme.numberInput.iconAccept
                backtabUp: buttonReject
                tabUp: buttonMinus100K
                onReleased: root.result(true, root.number)
            }
        } // end Grid numberPad
    }
}
